Method: Filemaker::Model::Pagination#__per
- Defined in:
- lib/filemaker/model/pagination.rb
#__per ⇒ Object
A simple getter to retrieve the limit value. It will default to Model.per_page
Will have stacklevel too deep if we have ‘per(nil)`. Somehow, the per_page must be set either at the Model.per_page, Kaminari.config.default_per_page, or right here where I just throw a 25 value at it.
31 32 33 34 |
# File 'lib/filemaker/model/pagination.rb', line 31 def __per per(klass.per_page || 25) unless limit? [:max] end |